@@ -1,7 +1,9 @@
-Index: geos/src/index/bintree/Root.cpp
-===================================================================
---- geos.orig/src/index/bintree/Root.cpp	2013-12-06 13:44:06.528007604 +0100
-+++ geos/src/index/bintree/Root.cpp	2013-12-06 13:44:06.524007594 +0100
+Description: Include cstddef and use std namespace.
+ Fix a missing cstddef header file inclusion in some files and use
+ of std namespace. This is required in current default gcc flavor.
+Author: Francesco Paolo Lovergine <frankie@debian.org>
+--- a/src/index/bintree/Root.cpp
++++ b/src/index/bintree/Root.cpp
 @@ -20,11 +20,14 @@
  
  #include <cstddef>
@@ -17,10 +19,8 @@ Index: geos/src/index/bintree/Root.cpp
  double Root::origin=0.0;
  
  void
-Index: geos/src/index/quadtree/Root.cpp
-===================================================================
---- geos.orig/src/index/quadtree/Root.cpp	2013-12-06 13:44:06.528007604 +0100
-+++ geos/src/index/quadtree/Root.cpp	2013-12-06 13:44:06.524007594 +0100
+--- a/src/index/quadtree/Root.cpp
++++ b/src/index/quadtree/Root.cpp
 @@ -24,6 +24,7 @@
  #include <geos/geom/Envelope.h>
  
@@ -29,7 +29,7 @@ Index: geos/src/index/quadtree/Root.cpp
  
  #ifndef GEOS_DEBUG
  #define GEOS_DEBUG 0
-@@ -39,6 +40,8 @@
+@@ -39,6 +40,8 @@ namespace geos {
  namespace index { // geos.index
  namespace quadtree { // geos.index.quadtree
  
